@@ -45,12 +45,11 @@ public class NonDurableCursorImpl extends ManagedCursorImpl {
         // Compare with "latest" position marker by using only the ledger id. Since the C++ client is using 48bits to
         // store the entryId, it's not able to pass a Long.max() as entryId. In this case there's no point to require
         // both ledgerId and entryId to be Long.max()
-        Pair<Position, Long> lastPositionCounter = ledger.getLastPositionAndCounter();
-        if (startCursorPosition == null || startCursorPosition.compareTo(lastPositionCounter.getLeft()) > 0) {
+        if (startCursorPosition == null || startCursorPosition.compareTo(ledger.lastConfirmedEntry) > 0) {
             // Start from last entry
             switch (initialPosition) {
                 case Latest:
-                    initializeCursorPosition(lastPositionCounter);
+                    initializeCursorPosition(ledger.getLastPositionAndCounter());
                     break;
                 case Earliest:
                     initializeCursorPosition(ledger.getFirstPositionAndCounter());
@@ -72,6 +71,7 @@ public class NonDurableCursorImpl extends ManagedCursorImpl {
     private void recoverCursor(Position mdPosition) {
         Pair<Position, Long> lastEntryAndCounter = ledger.getLastPositionAndCounter();
         this.readPosition = isReadCompacted() ? mdPosition.getNext() : ledger.getNextValidPosition(mdPosition);
+        ledger.onCursorReadPositionUpdated(this, readPosition);
         markDeletePosition = ledger.getPreviousPosition(this.readPosition);
 
         // Initialize the counter such that the difference between the messages written on the ML and the
@@ -100,20 +100,11 @@ public class NonDurableCursorImpl extends ManagedCursorImpl {
 
     @Override
     protected void internalAsyncMarkDelete(final Position newPosition, Map<String, Long> properties,
-            final MarkDeleteCallback callback, final Object ctx, Runnable alignAcknowledgeStatusAfterPersisted) {
+            final MarkDeleteCallback callback, final Object ctx) {
         // Bypass persistence of mark-delete position and individually deleted messages info
-        MarkDeleteEntry mdEntry;
-        lock.writeLock().lock();
-        try {
-            // use given properties or when missing, use the properties from the previous field value
-            Map<String, Long> propertiesToUse = properties != null ? properties : getProperties();
-            mdEntry = new MarkDeleteEntry(newPosition, propertiesToUse, callback, ctx,
-                    alignAcknowledgeStatusAfterPersisted);
-            lastMarkDeleteEntry = mdEntry;
-            mdEntry.alignAcknowledgeStatus();
-        } finally {
-            lock.writeLock().unlock();
-        }
+
+        MarkDeleteEntry mdEntry = new MarkDeleteEntry(newPosition, properties, callback, ctx);
+        lastMarkDeleteEntry = mdEntry;
         // it is important to advance cursor so the retention can kick in as expected.
         ledger.onCursorMarkDeletePositionUpdated(NonDurableCursorImpl.this, mdEntry.newPosition);
 
@@ -146,6 +137,7 @@ public class NonDurableCursorImpl extends ManagedCursorImpl {
             super.rewind();
         } else {
             readPosition = markDeletePosition.getNext();
+            ledger.onCursorReadPositionUpdated(this, readPosition);
         }
     }
 
