@@ -231,7 +231,7 @@ public class OpAddEntry implements AddCallback, CloseCallback, Runnable, Managed
         }
 
         if (rc != BKException.Code.OK || timeoutTriggered.get()) {
-            handleAddFailure(lh, rc);
+            handleAddFailure(lh);
         } else {
             // Trigger addComplete callback in a thread hashed on the managed ledger name
             ml.getExecutor().execute(this);
@@ -259,13 +259,21 @@ public class OpAddEntry implements AddCallback, CloseCallback, Runnable, Managed
 
         long ledgerId = ledger != null ? ledger.getId() : ((Position) ctx).getLedgerId();
         // Don't insert to the entry cache for the ShadowManagedLedger
-        if (!(ml instanceof ShadowManagedLedgerImpl) && ml.hasActiveCursors()) {
+        if (!(ml instanceof ShadowManagedLedgerImpl)) {
             // Avoid caching entries if no cursor has been created
-            EntryImpl entry = EntryImpl.create(ledgerId, entryId, data);
-            // EntryCache.insert: duplicates entry by allocating new entry and data. so, recycle entry after calling
-            // insert
-            ml.entryCache.insert(entry);
-            entry.release();
+            if (ml.getActiveCursors().shouldCacheAddedEntry()) {
+                int expectedReadCount = 0;
+                // only use expectedReadCount if cache eviction is enabled by expected read count
+                if (ml.getConfig().isCacheEvictionByExpectedReadCount()) {
+                    expectedReadCount = ml.getActiveCursors().size();
+                }
+                EntryImpl entry = EntryImpl.create(ledgerId, entryId, data, expectedReadCount);
+                entry.setDecreaseReadCountOnRelease(false);
+                // EntryCache.insert: duplicates entry by allocating new entry and data. so, recycle entry after calling
+                // insert
+                ml.entryCache.insert(entry);
+                entry.release();
+            }
         }
 
         Position lastEntry = PositionFactory.create(ledgerId, entryId);
@@ -343,7 +351,7 @@ public class OpAddEntry implements AddCallback, CloseCallback, Runnable, Managed
      *
      * @param lh
      */
-    void handleAddFailure(final LedgerHandle lh, Integer rc) {
+    void handleAddFailure(final LedgerHandle lh) {
         // If we get a write error, we will try to create a new ledger and re-submit the pending writes. If the
         // ledger creation fails (persistent bk failure, another instance owning the ML, ...), then the writes will
         // be marked as failed.
@@ -353,15 +361,7 @@ public class OpAddEntry implements AddCallback, CloseCallback, Runnable, Managed
         finalMl.getExecutor().execute(() -> {
             // Force the creation of a new ledger. Doing it in a background thread to avoid acquiring ML lock
             // from a BK callback.
-            // If we received a "MetadataVersionException" or a "LedgerFencedException", we should tell the ML that
-            // the ledger has been closed by others, and the entries count in the ledger may is not correct. The ML
-            // will handle it.
-            if (rc != null && (rc.intValue() == BKException.Code.MetadataVersionException
-                    || rc.intValue() == BKException.Code.LedgerFencedException)) {
-                finalMl.addEntryFailedDueToConcurrentlyModified(lh, rc);
-            } else {
-                finalMl.ledgerClosed(lh);
-            }
+            finalMl.ledgerClosed(lh);
         });
     }
 
