@@ -19,8 +19,6 @@
 package org.apache.bookkeeper.mledger.impl;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
-import static org.apache.bookkeeper.mledger.impl.ManagedLedgerImpl.ENTRIES_ADDED_COUNTER_UPDATER;
-import static org.assertj.core.api.AssertionsForInterfaceTypes.assertThat;
 import static org.testng.Assert.assertEquals;
 import static org.testng.Assert.assertFalse;
 import static org.testng.Assert.assertNotEquals;
@@ -51,13 +49,7 @@ import org.apache.bookkeeper.mledger.ManagedLedgerFactory;
 import org.apache.bookkeeper.mledger.ManagedLedgerFactoryConfig;
 import org.apache.bookkeeper.mledger.Position;
 import org.apache.bookkeeper.mledger.PositionFactory;
-import org.apache.bookkeeper.mledger.util.ManagedLedgerTestUtil;
 import org.apache.bookkeeper.test.MockedBookKeeperTestCase;
-import org.apache.commons.lang3.tuple.Pair;
-import org.apache.pulsar.common.api.proto.CommandSubscribe;
-import org.awaitility.Awaitility;
-import org.mockito.Mockito;
-import org.mockito.stubbing.Answer;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.testng.Assert;
@@ -111,58 +103,6 @@ public class NonDurableCursorTest extends MockedBookKeeperTestCase {
         ledger.close();
     }
 
-    @Test(timeOut = 20000)
-    void testOpenNonDurableCursorWhileLedgerIsAddingFirstEntryAfterTrimmed() throws Exception {
-        ManagedLedgerConfig config = new ManagedLedgerConfig().setMaxEntriesPerLedger(1)
-                .setRetentionTime(0, TimeUnit.MILLISECONDS);
-        config.setMinimumRolloverTime(0, TimeUnit.MILLISECONDS);
-        @Cleanup
-        ManagedLedgerImpl ledgerSpy =
-                Mockito.spy((ManagedLedgerImpl) factory.open("non_durable_cursor_while_ledger_trimmed", config));
-
-        ledgerSpy.addEntry("message1".getBytes());
-
-        ledgerSpy.rollCurrentLedgerIfFull();
-        Awaitility.waitAtMost(5, TimeUnit.SECONDS).until(() ->
-                ledgerSpy.getLedgersInfoAsList().size() > 1
-        );
-        CompletableFuture<Void> trimFuture = new CompletableFuture<>();
-        ledgerSpy.trimConsumedLedgersInBackground(trimFuture);
-        trimFuture.join();
-
-        // Use (currentLedgerId, -1) as startCursorPosition after ledger was trimmed
-        Position startCursorPosition = PositionFactory.create(ledgerSpy.getCurrentLedger().getId(), -1);
-        assertTrue(startCursorPosition.compareTo(ledgerSpy.lastConfirmedEntry) > 0);
-
-        CountDownLatch getLastPositionLatch = new CountDownLatch(1);
-        CountDownLatch newNonDurableCursorLatch = new CountDownLatch(1);
-        Mockito.when(ledgerSpy.getLastPositionAndCounter()).then((Answer<Pair<Position, Long>>) invocation -> {
-            newNonDurableCursorLatch.countDown();
-            getLastPositionLatch.await();
-            return Pair.of(ledgerSpy.lastConfirmedEntry, ENTRIES_ADDED_COUNTER_UPDATER.get(ledgerSpy));
-        });
-
-        CompletableFuture<ManagedCursor> cursorFuture = new CompletableFuture<ManagedCursor>()
-                .completeAsync(() ->
-                        new NonDurableCursorImpl(bkc, ledgerSpy, "my_test_cursor",
-                                startCursorPosition, CommandSubscribe.InitialPosition.Latest, false)
-                );
-        Position oldLastConfirmedEntry = ledgerSpy.lastConfirmedEntry;
-
-        // Wait until NonDurableCursorImpl constructor invokes ManagedLedgerImpl.getLastPositionAndCounter
-        newNonDurableCursorLatch.await();
-        // Add first entry after ledger was trimmed
-        ledgerSpy.addEntry("message2".getBytes());
-        assertTrue(oldLastConfirmedEntry.compareTo(ledgerSpy.lastConfirmedEntry) < 0);
-
-        // Unblock NonDurableCursorImpl constructor
-        getLastPositionLatch.countDown();
-
-        // cursor should read from lastConfirmedEntry
-        ManagedCursor cursor = cursorFuture.join();
-        assertEquals(cursor.getReadPosition(), ledgerSpy.lastConfirmedEntry);
-    }
-
     @Test(timeOut = 20000)
     void testZNodeBypassed() throws Exception {
         ManagedLedger ledger = factory.open("my_test_ledger");
@@ -569,18 +509,16 @@ public class NonDurableCursorTest extends MockedBookKeeperTestCase {
         }
 
         latch.await();
+
         assertEquals(c1.getNumberOfEntries(), 0);
 
         // Reopen
         @Cleanup("shutdown")
         ManagedLedgerFactory factory2 = new ManagedLedgerFactoryImpl(metadataStore, bkc);
-        ledger = ManagedLedgerTestUtil.retry(() -> factory2.open("my_test_ledger"));
+        ledger = factory2.open("my_test_ledger");
         ManagedCursor c2 = ledger.openCursor("c1");
 
-        // Since all entries are consumed, we should move mark delete position to nextLedgerId:-1.
-        // See PR https://github.com/apache/pulsar/pull/25087.
-        Awaitility.await().untilAsserted(
-                () -> assertThat(c2.getMarkDeletedPosition()).isGreaterThanOrEqualTo(lastPosition.get()));
+        assertEquals(c2.getMarkDeletedPosition(), lastPosition.get());
     }
 
     @Test(timeOut = 20000)
@@ -728,31 +666,31 @@ public class NonDurableCursorTest extends MockedBookKeeperTestCase {
 
         ManagedCursor cursor1 = ledger.openCursor(c1);
         cursor1.seek(p3);
-        assertEquals(p3, ledger.getCursors().getSlowestReaderPosition());
+        assertEquals(p3, ledger.getCursors().getSlowestCursorPosition());
 
         ManagedCursor nonCursor1 = ledger.newNonDurableCursor(p2, nc1);
         // The slowest reader should still be the durable cursor since non-durable readers are not taken into account
-        assertEquals(p3, ledger.getCursors().getSlowestReaderPosition());
+        assertEquals(p3, ledger.getCursors().getSlowestCursorPosition());
 
         Position earliestPos = PositionFactory.create(-1, -2);
 
         ManagedCursor nonCursorEarliest = ledger.newNonDurableCursor(earliestPos, ncEarliest);
 
         // The slowest reader should still be the durable cursor since non-durable readers are not taken into account
-        assertEquals(p3, ledger.getCursors().getSlowestReaderPosition());
+        assertEquals(p3, ledger.getCursors().getSlowestCursorPosition());
 
         // move non-durable cursor should NOT update the slowest reader position
         nonCursorEarliest.markDelete(p1);
-        assertEquals(p3, ledger.getCursors().getSlowestReaderPosition());
+        assertEquals(p3, ledger.getCursors().getSlowestCursorPosition());
 
         nonCursorEarliest.markDelete(p2);
-        assertEquals(p3, ledger.getCursors().getSlowestReaderPosition());
+        assertEquals(p3, ledger.getCursors().getSlowestCursorPosition());
 
         nonCursorEarliest.markDelete(p3);
-        assertEquals(p3, ledger.getCursors().getSlowestReaderPosition());
+        assertEquals(p3, ledger.getCursors().getSlowestCursorPosition());
 
         nonCursor1.markDelete(p3);
-        assertEquals(p3, ledger.getCursors().getSlowestReaderPosition());
+        assertEquals(p3, ledger.getCursors().getSlowestCursorPosition());
 
         ledger.close();
     }
