@@ -37,6 +37,7 @@ import org.apache.bookkeeper.mledger.ManagedCursor;
 import org.apache.bookkeeper.mledger.ManagedLedgerConfig;
 import org.apache.bookkeeper.mledger.ManagedLedgerException;
 import org.apache.bookkeeper.mledger.Position;
+import org.apache.bookkeeper.mledger.PositionFactory;
 import org.apache.bookkeeper.mledger.proto.MLDataFormats;
 import org.apache.bookkeeper.mledger.util.MockClock;
 import org.apache.bookkeeper.test.MockedBookKeeperTestCase;
@@ -163,7 +164,7 @@ public class OffloadLedgerDeleteTest extends MockedBookKeeperTestCase {
         config.setLedgerOffloader(offloader);
         config.setClock(clock);
 
-        ManagedLedgerImpl ledger = (ManagedLedgerImpl)factory.open("my_test_ledger", config);
+        ManagedLedgerImpl ledger = (ManagedLedgerImpl) factory.open("my_test_ledger", config);
         int i = 0;
         for (; i < 15; i++) {
             String content = "entry-" + i;
@@ -227,7 +228,7 @@ public class OffloadLedgerDeleteTest extends MockedBookKeeperTestCase {
         offloader.getOffloadPolicies().setManagedLedgerOffloadedReadPriority(OffloadedReadPriority.BOOKKEEPER_FIRST);
         config.setLedgerOffloader(offloader);
         ManagedLedgerImpl ml =
-                (ManagedLedgerImpl)factory.open("testGetReadLedgerHandleAfterTrimOffloadedLedgers", config);
+                (ManagedLedgerImpl) factory.open("testGetReadLedgerHandleAfterTrimOffloadedLedgers", config);
         ml.openCursor("c1");
 
         // Write entries.
@@ -244,7 +245,7 @@ public class OffloadLedgerDeleteTest extends MockedBookKeeperTestCase {
 
         // Offload ledgers.
         Thread.sleep(offloadThresholdSeconds * 2 * 1000);
-        CompletableFuture<PositionImpl> offloadFuture = new CompletableFuture<PositionImpl>();
+        CompletableFuture<Position> offloadFuture = new CompletableFuture<Position>();
         ml.maybeOffloadInBackground(offloadFuture);
         offloadFuture.join();
 
@@ -262,10 +263,10 @@ public class OffloadLedgerDeleteTest extends MockedBookKeeperTestCase {
                 readCountDownLatch.countDown();
             }
         };
-        ml.asyncReadEntry(PositionImpl.get(ledger1, 0), readCb, null);
-        ml.asyncReadEntry(PositionImpl.get(ledger2, 0), readCb, null);
-        ml.asyncReadEntry(PositionImpl.get(ledger3, 0), readCb, null);
-        ml.asyncReadEntry(PositionImpl.get(ledger4, 0), readCb, null);
+        ml.asyncReadEntry(PositionFactory.create(ledger1, 0), readCb, null);
+        ml.asyncReadEntry(PositionFactory.create(ledger2, 0), readCb, null);
+        ml.asyncReadEntry(PositionFactory.create(ledger3, 0), readCb, null);
+        ml.asyncReadEntry(PositionFactory.create(ledger4, 0), readCb, null);
         readCountDownLatch.await();
         ReadHandle originalReadHandle4 = ml.getLedgerHandle(ledger4).join();
 
@@ -392,7 +393,7 @@ public class OffloadLedgerDeleteTest extends MockedBookKeeperTestCase {
         config.setLedgerOffloader(offloader);
         config.setClock(clock);
 
-        ManagedLedgerImpl ledger = (ManagedLedgerImpl)factory.open("my_test_ledger", config);
+        ManagedLedgerImpl ledger = (ManagedLedgerImpl) factory.open("my_test_ledger", config);
         int i = 0;
         for (; i < 15; i++) {
             String content = "entry-" + i;
@@ -439,7 +440,7 @@ public class OffloadLedgerDeleteTest extends MockedBookKeeperTestCase {
         config.setLedgerOffloader(offloader);
         config.setClock(clock);
 
-        ManagedLedgerImpl ledger = (ManagedLedgerImpl)factory.open("my_test_ledger", config);
+        ManagedLedgerImpl ledger = (ManagedLedgerImpl) factory.open("my_test_ledger", config);
         ManagedCursor cursor = ledger.openCursor("sub1");
 
         for (int i = 0; i < 15; i++) {
