@@ -493,6 +493,7 @@ public class TransferShedder implements NamespaceUnloadStrategy {
                 }
 
                 int remainingTopBundles = maxBrokerTopBundlesLoadData.size();
+                Set<String> sheddingExcludedNamespaces = conf.getLoadBalancerSheddingExcludedNamespaces();
                 for (var e : maxBrokerTopBundlesLoadData) {
                     String bundle = e.bundleName();
                     if (channel != null && !channel.isOwner(bundle, maxBroker)) {
@@ -502,6 +503,14 @@ public class TransferShedder implements NamespaceUnloadStrategy {
                         }
                         continue;
                     }
+                    final String namespaceName = NamespaceBundle.getBundleNamespace(bundle);
+                    if (sheddingExcludedNamespaces.contains(namespaceName)) {
+                        if (debugMode) {
+                            log.info(String.format(CANNOT_UNLOAD_BUNDLE_MSG
+                                    + " Bundle namespace has been found in sheddingExcludedNamespaces", bundle));
+                        }
+                        continue;
+                    }
                     if (recentlyUnloadedBundles.containsKey(bundle)) {
                         if (debugMode) {
                             log.info(String.format(CANNOT_UNLOAD_BUNDLE_MSG
