@@ -170,25 +170,16 @@ public class PersistentStickyKeyDispatcherMultipleConsumers extends PersistentDi
 
     private synchronized void registerDrainingHashes(Consumer skipConsumer,
                                                      ImpactedConsumersResult impactedConsumers) {
-        impactedConsumers.processUpdatedHashRanges((c, updatedHashRanges, opType) -> {
+        impactedConsumers.processRemovedHashRanges((c, removedHashRanges) -> {
             if (c != skipConsumer) {
                 c.getPendingAcks().forEach((ledgerId, entryId, batchSize, stickyKeyHash) -> {
                     if (stickyKeyHash == STICKY_KEY_HASH_NOT_SET) {
                         log.warn("[{}] Sticky key hash was missing for {}:{}", getName(), ledgerId, entryId);
                         return;
                     }
-                    if (updatedHashRanges.containsStickyKey(stickyKeyHash)) {
-                        switch (opType) {
-                            //reduce ref count in case the stickyKeyHash was re-assigned to the original consumer
-                            case ADD -> {
-                                var entry = drainingHashesTracker.getEntry(stickyKeyHash);
-                                if (entry != null && entry.getConsumer() == c) {
-                                    drainingHashesTracker.reduceRefCount(c, stickyKeyHash, false);
-                                }
-                            }
-                            // add the pending ack to the draining hashes tracker if the hash is in the range
-                            case REMOVE -> drainingHashesTracker.addEntry(c, stickyKeyHash);
-                        }
+                    if (removedHashRanges.containsStickyKey(stickyKeyHash)) {
+                        // add the pending ack to the draining hashes tracker if the hash is in the range
+                        drainingHashesTracker.addEntry(c, stickyKeyHash);
                     }
                 });
             }
@@ -475,6 +466,10 @@ public class PersistentStickyKeyDispatcherMultipleConsumers extends PersistentDi
                     // the entry is blocked by hash, add the consumer to the blocked set
                     blockedByHashConsumers.add(consumer);
                 }
+                if (entry.getReadCountHandler() != null) {
+                    // increment the expected read count for the entry, so that it can be cached for a longer time
+                    entry.getReadCountHandler().incrementExpectedReadCount();
+                }
                 // add the message to replay
                 addMessageToReplay(entry.getLedgerId(), entry.getEntryId(), stickyKeyHash);
                 // release the entry as it will not be dispatched
