@@ -18,6 +18,9 @@
  */
 package org.apache.pulsar.broker;
 
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyInt;
+import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
@@ -26,24 +29,52 @@ import static org.testng.Assert.assertTrue;
 import static org.testng.Assert.fail;
 import io.netty.buffer.ByteBuf;
 import io.netty.buffer.UnpooledByteBufAllocator;
+import java.util.Map;
+import java.util.concurrent.ExecutionException;
+import java.util.concurrent.Executors;
+import java.util.concurrent.ScheduledExecutorService;
+import java.util.concurrent.TimeUnit;
+import org.apache.bookkeeper.mledger.AsyncCallbacks;
+import org.apache.bookkeeper.mledger.ManagedCursor;
 import org.apache.bookkeeper.mledger.ManagedLedger;
 import org.apache.pulsar.broker.service.Topic;
 import org.apache.pulsar.broker.service.persistent.MessageDeduplication;
 import org.apache.pulsar.broker.service.persistent.PersistentTopic;
+import org.apache.pulsar.client.util.ExecutorProvider;
 import org.apache.pulsar.common.api.proto.MarkerType;
 import org.apache.pulsar.common.api.proto.MessageMetadata;
+import org.testng.annotations.AfterMethod;
+import org.testng.annotations.BeforeMethod;
 import org.testng.annotations.Test;
 
 public class BrokerMessageDeduplicationTest {
 
+    private ManagedLedger managedLedger;
+    private MessageDeduplication deduplication;
+    private ScheduledExecutorService executor;
+
+    @BeforeMethod
+    public void setUp() {
+        final var pulsarService = mock(PulsarService.class);
+        final var configuration = new ServiceConfiguration();
+        configuration.setBrokerDeduplicationEntriesInterval(10);
+        doReturn(configuration).when(pulsarService).getConfiguration();
+        executor = Executors.newScheduledThreadPool(1, new ExecutorProvider.ExtendedThreadFactory("pulsar"));
+        doReturn(executor).when(pulsarService).getExecutor();
+        managedLedger = mock(ManagedLedger.class);
+        final var mockTopic = mock(PersistentTopic.class);
+        doReturn(true).when(mockTopic).isDeduplicationEnabled();
+        deduplication = spy(new MessageDeduplication(pulsarService, mockTopic, managedLedger));
+        doReturn(true).when(deduplication).isEnabled();
+    }
+
+    @AfterMethod
+    public void tearDown() {
+        executor.shutdown();
+    }
+
     @Test
     public void markerMessageNotDeduplicated() {
-        PulsarService pulsarService = mock(PulsarService.class);
-        ServiceConfiguration configuration = new ServiceConfiguration();
-        doReturn(configuration).when(pulsarService).getConfiguration();
-        MessageDeduplication deduplication = spy(new MessageDeduplication(pulsarService,
-                mock(PersistentTopic.class), mock(ManagedLedger.class)));
-        doReturn(true).when(deduplication).isEnabled();
         Topic.PublishContext context = mock(Topic.PublishContext.class);
         doReturn(true).when(context).isMarkerMessage();
 
@@ -63,12 +94,6 @@ public class BrokerMessageDeduplicationTest {
 
     @Test
     public void markerMessageNotRecordPersistent() {
-        PulsarService pulsarService = mock(PulsarService.class);
-        ServiceConfiguration configuration = new ServiceConfiguration();
-        doReturn(configuration).when(pulsarService).getConfiguration();
-        MessageDeduplication deduplication = spy(new MessageDeduplication(pulsarService,
-                mock(PersistentTopic.class), mock(ManagedLedger.class)));
-        doReturn(true).when(deduplication).isEnabled();
         Topic.PublishContext context = mock(Topic.PublishContext.class);
          // marker message don't record message persisted.
         doReturn(true).when(context).isMarkerMessage();
@@ -84,5 +109,24 @@ public class BrokerMessageDeduplicationTest {
         }
     }
 
-
+    @Test
+    public void checkStatusFail() throws Exception {
+        final var cursor = mock(ManagedCursor.class);
+        doAnswer(invocation -> {
+            ((AsyncCallbacks.OpenCursorCallback) invocation.getArgument(1)).openCursorComplete(cursor, null);
+            return null;
+        }).when(managedLedger).asyncOpenCursor(any(), any(), any());
+        doReturn(true).when(cursor).hasMoreEntries();
+        doReturn(Map.of()).when(cursor).getProperties();
+        try {
+            doAnswer(invocation -> {
+                throw new RuntimeException("asyncReadEntries failed");
+            }).when(cursor).asyncReadEntries(anyInt(), any(), any(), any());
+            deduplication.checkStatus().get(3, TimeUnit.SECONDS);
+            fail();
+        } catch (ExecutionException e) {
+            assertTrue(e.getCause() instanceof RuntimeException);
+            assertTrue(e.getMessage().contains("asyncReadEntries failed"));
+        }
+    }
 }
