@@ -31,6 +31,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Optional;
 import java.util.Random;
+import java.util.Set;
 import org.apache.pulsar.broker.PulsarService;
 import org.apache.pulsar.broker.ServiceConfiguration;
 import org.apache.pulsar.broker.loadbalance.impl.LoadManagerShared;
@@ -136,6 +137,27 @@ public class TopKBundlesTest {
         assertEquals(top0.bundleName(), bundle1);
     }
 
+    @Test
+    public void testSheddingExcludedNamespaces() {
+        Map<String, NamespaceBundleStats> bundleStats = new HashMap<>();
+        var topKBundles = new TopKBundles(pulsar);
+        pulsar.getConfiguration().setLoadBalancerSheddingExcludedNamespaces(Set.of("my-tenant/my-namespace2"));
+        NamespaceBundleStats stats1 = new NamespaceBundleStats();
+        stats1.msgRateIn = 500;
+        bundleStats.put("my-tenant/my-namespace2/0x00000000_0x0FFFFFFF", stats1);
+
+        NamespaceBundleStats stats2 = new NamespaceBundleStats();
+        stats2.msgRateIn = 10000;
+        stats2.msgThroughputOut = 10;
+        bundleStats.put(bundle1, stats2);
+
+        topKBundles.update(bundleStats, 2);
+
+        assertEquals(topKBundles.getLoadData().getTopBundlesLoadData().size(), 1);
+        var top0 = topKBundles.getLoadData().getTopBundlesLoadData().get(0);
+        assertEquals(top0.bundleName(), bundle1);
+    }
+
     @Test
     public void testZeroMsgThroughputBundleStats() {
         Map<String, NamespaceBundleStats> bundleStats = new HashMap<>();
@@ -297,29 +319,4 @@ public class TopKBundlesTest {
             }
         }
     }
-
-    // Issue https://github.com/apache/pulsar/issues/24754
-    @Test
-    public void testPartitionSortCompareToContractViolationIssue() {
-        Random rnd = new Random(0);
-        ArrayList<NamespaceBundleStats> stats = new ArrayList<>();
-        for (int i = 0; i < 1000; ++i) {
-            NamespaceBundleStats s = new NamespaceBundleStats();
-            s.msgThroughputIn = 4 * 75000 * rnd.nextDouble();  // Just above threshold (1e5)
-            s.msgThroughputOut = 75000000 - (4 * (75000 * rnd.nextDouble()));
-            s.msgRateIn = 4 * 75 * rnd.nextDouble();
-            s.msgRateOut = 75000 - (4 * 75 * rnd.nextDouble());
-            s.topics = i;
-            s.consumerCount = i;
-            s.producerCount = 4 * rnd.nextInt(375);
-            s.cacheSize = 75000000 - (rnd.nextInt(4 * 75000));
-            stats.add(s);
-        }
-        List<Map.Entry<String, ? extends Comparable>> bundleEntries = new ArrayList<>();
-
-        for (NamespaceBundleStats s : stats) {
-            bundleEntries.add(Map.entry("bundle-" + s.msgThroughputIn, s));
-        }
-        TopKBundles.partitionSort(bundleEntries, 100);
-    }
 }
