@@ -21,17 +21,10 @@ package org.apache.pulsar.broker.service;
 import static org.apache.pulsar.broker.auth.MockedPulsarServiceBaseTest.retryStrategically;
 import static org.testng.Assert.assertEquals;
 import static org.testng.Assert.assertNotEquals;
-import static org.testng.Assert.assertNotNull;
 import static org.testng.Assert.assertThrows;
-import static org.testng.Assert.assertTrue;
 import static org.testng.Assert.fail;
 import com.google.common.collect.Sets;
-import io.netty.channel.EventLoopGroup;
-import io.netty.util.concurrent.DefaultThreadFactory;
-import java.io.Closeable;
 import java.lang.reflect.Field;
-import java.util.ArrayList;
-import java.util.List;
 import java.util.Map.Entry;
 import java.util.NavigableMap;
 import java.util.Optional;
@@ -43,7 +36,6 @@ import lombok.Cleanup;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.bookkeeper.client.BKException;
 import org.apache.bookkeeper.client.BookKeeper;
-import org.apache.bookkeeper.client.LedgerHandle;
 import org.apache.bookkeeper.client.api.LedgerMetadata;
 import org.apache.bookkeeper.mledger.ManagedLedgerConfig;
 import org.apache.bookkeeper.mledger.impl.ManagedCursorImpl;
@@ -56,18 +48,13 @@ import org.apache.pulsar.broker.service.persistent.PersistentTopic;
 import org.apache.pulsar.client.admin.PulsarAdminException;
 import org.apache.pulsar.client.api.Consumer;
 import org.apache.pulsar.client.api.Message;
-import org.apache.pulsar.client.api.MessageId;
-import org.apache.pulsar.client.api.MessageIdAdv;
 import org.apache.pulsar.client.api.Producer;
 import org.apache.pulsar.client.api.PulsarClient;
 import org.apache.pulsar.client.api.Schema;
-import org.apache.pulsar.common.policies.data.ManagedLedgerInternalStats;
 import org.apache.pulsar.common.policies.data.TenantInfoImpl;
-import org.apache.pulsar.common.util.netty.EventLoopUtil;
 import org.apache.zookeeper.ZooKeeper;
 import org.awaitility.Awaitility;
 import org.testng.Assert;
-import org.testng.annotations.DataProvider;
 import org.testng.annotations.Test;
 
 @Test(groups = "broker")
@@ -535,116 +522,4 @@ public class BrokerBkEnsemblesTest extends BkEnsemblesTestBase {
         assertEquals(pulsar.getBrokerService().getTopicIfExists(topic).join(), Optional.empty());
     }
 
-    @DataProvider
-    public Object[][] doReloadTopicAfterLedgerFenced() {
-        return new Object[][] {
-                {true},
-                {false}
-        };
-    }
-
-    @Test(timeOut = 60_000, dataProvider = "doReloadTopicAfterLedgerFenced")
-    public void testConcurrentlyModifyCurrentLedger(boolean doReloadTopicAfterLedgerFenced) throws Exception {
-        EventLoopGroup eventLoopGroup = EventLoopUtil.newEventLoopGroup(config.getNumIOThreads(),
-                config.isEnableBusyWait(), new DefaultThreadFactory("pulsar-io-test-1"));
-        BookKeeper bkClient2 = pulsar.getBkClientFactory().create(pulsar.getConfiguration(),
-                pulsar.getLocalMetadataStore(),
-                eventLoopGroup,
-                Optional.empty(),
-                null).get();
-
-        final String namespace = BrokerTestUtil.newUniqueName("prop/usc");
-        final String topic = BrokerTestUtil.newUniqueName("persistent://" + namespace + "/tp");
-        final String subscription = "s1";
-        admin.namespaces().createNamespace(namespace);
-        admin.topics().createNonPartitionedTopic(topic);
-        admin.topics().createSubscription(topic, subscription, MessageId.earliest);
-        PersistentTopic persistentTopic = (PersistentTopic) pulsar.getBrokerService()
-                .getTopic(topic, false).join().get();
-        ManagedLedgerImpl ml = (ManagedLedgerImpl) persistentTopic.getManagedLedger();
-
-        @Cleanup
-        PulsarClient client = PulsarClient.builder()
-                .serviceUrl(pulsar.getBrokerServiceUrl())
-                .statsInterval(0, TimeUnit.SECONDS)
-                .build();
-        Producer<String> producer = client.newProducer(Schema.STRING)
-                .enableBatching(false)
-                .topic(topic)
-                .create();
-        MessageIdAdv msgId = (MessageIdAdv) producer.send("1");
-        long currentLedgerId = msgId.getLedgerId();
-
-        // Make an injection to let the next publishing delay.
-        Closeable cancellation = injectBKServerDelayForCurrentLedger(topic, 10, TimeUnit.SECONDS, 0);
-
-        // Publish new 3 messages.
-        // Since we injected a delay, the 2nd message will complete after the ledger is closed.
-        // After the ledger is closed, the 5th messages will be written to a new ledger.
-        // Verify: the entries in topic and stored are consistent.
-        CompletableFuture<MessageId> send2 = producer.sendAsync("2");
-        CompletableFuture<MessageId> send3 = producer.sendAsync("3");
-        CompletableFuture<MessageId> send4 = producer.sendAsync("4");
-        // Wait 1s to make sure the messages are written to the Bookie server.
-        Thread.sleep(1000);
-        LedgerHandle readOnlyLedger = bkClient2.openLedger(currentLedgerId,
-                BookKeeper.DigestType.fromApiDigestType(ml.getConfig().getDigestType()),
-                ml.getConfig().getPassword());
-        cancellation.close();
-        if (doReloadTopicAfterLedgerFenced) {
-            admin.topics().unload(topic);
-        }
-        producer.send("5");
-
-        // Verify: the entries in topic and stored are consistent.
-        List<ManagedLedgerInternalStats.LedgerInfo> ledgers = admin.topics().getInternalStats(topic).getLedgers();
-        ManagedLedgerInternalStats.LedgerInfo ledgerInfo = null;
-        for (ManagedLedgerInternalStats.LedgerInfo li : ledgers) {
-            if (li.ledgerId == currentLedgerId) {
-                ledgerInfo = li;
-                break;
-            }
-        }
-        assertNotNull(ledgerInfo);
-        long entriesStored = readOnlyLedger.getLedgerMetadata().getLastEntryId() + 1;
-        assertEquals(ledgerInfo.entries, entriesStored);
-
-        // Verify: the messages that got a successful response are persisted into the topic.
-        Consumer<String> consumer = client.newConsumer(Schema.STRING)
-                .topic(topic)
-                .subscriptionName(subscription)
-                .subscribe();
-        Awaitility.await().until(() -> send4.isDone());
-        List<String> messagesReceived = new ArrayList<>();
-        while (true) {
-            Message<String> msg = consumer.receive(2, TimeUnit.SECONDS);
-            if (msg != null) {
-                messagesReceived.add(msg.getValue());
-                consumer.acknowledge(msg);
-            } else {
-                break;
-            }
-        }
-        assertTrue(messagesReceived.contains("1"));
-        if (send2.isDone() && !send2.isCompletedExceptionally()) {
-            assertTrue(ledgerInfo.entries >= 1);
-            assertTrue(messagesReceived.contains("2"));
-        }
-        if (send3.isDone() && !send3.isCompletedExceptionally()) {
-            assertTrue(ledgerInfo.entries >= 2);
-            assertTrue(messagesReceived.contains("3"));
-        }
-        if (send4.isDone() && !send4.isCompletedExceptionally()) {
-            assertTrue(ledgerInfo.entries >= 2);
-            assertTrue(messagesReceived.contains("4"));
-        }
-        assertTrue(messagesReceived.contains("5"));
-
-        // cleanup.
-        producer.close();
-        admin.topics().unload(topic);
-        admin.topics().delete(topic);
-        bkClient2.close();
-    }
-
 }
