@@ -160,7 +160,8 @@ public class InactiveTopicDeleteTest extends BrokerTestBase {
         Awaitility.await()
                 .untilAsserted(() -> Assert.assertFalse(admin.topics().getList(namespace).contains(topic2)));
         Assert.assertTrue(admin.topics().getPartitionedTopicList(namespace).contains(topic));
-        // BrokerDeleteInactivePartitionedTopicMetaDataEnabled is not enabled, so only NonPartitionedTopic will be cleaned
+        // BrokerDeleteInactivePartitionedTopicMetaDataEnabled is not enabled,
+        // so only NonPartitionedTopic will be cleaned
         Assert.assertFalse(admin.topics().getList(namespace).contains(topic2));
     }
 
@@ -174,7 +175,8 @@ public class InactiveTopicDeleteTest extends BrokerTestBase {
         conf.setBrokerDeleteInactiveTopicsEnabled(true);
         conf.setBrokerDeleteInactiveTopicsMaxInactiveDurationSeconds(1000);
         conf.setBrokerDeleteInactiveTopicsMode(InactiveTopicDeleteMode.delete_when_no_subscriptions);
-        InactiveTopicPolicies defaultPolicy = new InactiveTopicPolicies(InactiveTopicDeleteMode.delete_when_no_subscriptions
+        InactiveTopicPolicies defaultPolicy =
+                new InactiveTopicPolicies(InactiveTopicDeleteMode.delete_when_no_subscriptions
                 , 1000, true);
 
         super.baseSetup();
@@ -222,12 +224,14 @@ public class InactiveTopicDeleteTest extends BrokerTestBase {
                     .get()).getInactiveTopicPolicies();
             return temp.getMaxInactiveDurationSeconds() == 1000;
         });
-        assertEquals(((PersistentTopic) pulsar.getBrokerService().getTopic(topic, false).get().get()).getInactiveTopicPolicies(), defaultPolicy);
+        assertEquals(((PersistentTopic) pulsar.getBrokerService().getTopic(topic, false)
+                .get().get()).getInactiveTopicPolicies(), defaultPolicy);
 
         policies = ((PersistentTopic) pulsar.getBrokerService().getTopic(topic2, false).get()
                 .get()).getInactiveTopicPolicies();
         Assert.assertTrue(policies.isDeleteWhileInactive());
-        assertEquals(policies.getInactiveTopicDeleteMode(), InactiveTopicDeleteMode.delete_when_subscriptions_caught_up);
+        assertEquals(policies.getInactiveTopicDeleteMode(),
+                InactiveTopicDeleteMode.delete_when_subscriptions_caught_up);
         assertEquals(policies.getMaxInactiveDurationSeconds(), 1);
         assertEquals(policies, admin.namespaces().getInactiveTopicPolicies(namespace2));
 
@@ -237,7 +241,8 @@ public class InactiveTopicDeleteTest extends BrokerTestBase {
                     .get()).getInactiveTopicPolicies();
             return temp.getMaxInactiveDurationSeconds() == 1000;
         });
-        assertEquals(((PersistentTopic) pulsar.getBrokerService().getTopic(topic2, false).get().get()).getInactiveTopicPolicies()
+        assertEquals(((PersistentTopic) pulsar.getBrokerService().getTopic(topic2, false)
+                        .get().get()).getInactiveTopicPolicies()
                 , defaultPolicy);
     }
 
@@ -277,7 +282,7 @@ public class InactiveTopicDeleteTest extends BrokerTestBase {
         // namespace use delete_when_no_subscriptions, namespace2 use delete_when_subscriptions_caught_up
         // namespace3 use default:delete_when_no_subscriptions
         InactiveTopicPolicies inactiveTopicPolicies =
-                new InactiveTopicPolicies(InactiveTopicDeleteMode.delete_when_no_subscriptions,1,true);
+                new InactiveTopicPolicies(InactiveTopicDeleteMode.delete_when_no_subscriptions, 1, true);
         admin.namespaces().setInactiveTopicPolicies(namespace, inactiveTopicPolicies);
         inactiveTopicPolicies.setInactiveTopicDeleteMode(InactiveTopicDeleteMode.delete_when_subscriptions_caught_up);
         admin.namespaces().setInactiveTopicPolicies(namespace2, inactiveTopicPolicies);
@@ -344,9 +349,9 @@ public class InactiveTopicDeleteTest extends BrokerTestBase {
         producer2.close();
         int receivedCount = 0;
         Message<byte[]> msg;
-        while((msg = consumer2.receive(1, TimeUnit.SECONDS)) != null) {
+        while ((msg = consumer2.receive(1, TimeUnit.SECONDS)) != null) {
             consumer2.acknowledge(msg);
-            receivedCount ++;
+            receivedCount++;
         }
         assertEquals(producedCount * 2, receivedCount);
 
@@ -419,7 +424,8 @@ public class InactiveTopicDeleteTest extends BrokerTestBase {
         conf.setBrokerDeleteInactiveTopicsEnabled(true);
         conf.setBrokerDeleteInactiveTopicsMaxInactiveDurationSeconds(1000);
         conf.setBrokerDeleteInactiveTopicsMode(InactiveTopicDeleteMode.delete_when_no_subscriptions);
-        InactiveTopicPolicies defaultPolicy = new InactiveTopicPolicies(InactiveTopicDeleteMode.delete_when_no_subscriptions
+        InactiveTopicPolicies defaultPolicy =
+                new InactiveTopicPolicies(InactiveTopicDeleteMode.delete_when_no_subscriptions
                 , 1000, true);
 
         super.baseSetup();
@@ -460,12 +466,14 @@ public class InactiveTopicDeleteTest extends BrokerTestBase {
         //Only the broker-level policies is set, so after removing the topic-level policies
         //, the topic will use the broker-level policies
         Awaitility.await().untilAsserted(()
-                -> assertEquals(((PersistentTopic) pulsar.getBrokerService().getTopic(topic, false).get().get()).getInactiveTopicPolicies()
-                , defaultPolicy));
+                -> assertEquals(((PersistentTopic) pulsar.getBrokerService().getTopic(topic, false)
+                        .get().get()).getInactiveTopicPolicies(), defaultPolicy));
 
-        policies = ((PersistentTopic)pulsar.getBrokerService().getTopic(topic2,false).get().get()).getInactiveTopicPolicies();
+        policies = ((PersistentTopic) pulsar.getBrokerService().getTopic(topic2, false)
+                .get().get()).getInactiveTopicPolicies();
         Assert.assertTrue(policies.isDeleteWhileInactive());
-        assertEquals(policies.getInactiveTopicDeleteMode(), InactiveTopicDeleteMode.delete_when_subscriptions_caught_up);
+        assertEquals(policies.getInactiveTopicDeleteMode(),
+                InactiveTopicDeleteMode.delete_when_subscriptions_caught_up);
         assertEquals(policies.getMaxInactiveDurationSeconds(), 1);
         assertEquals(policies, admin.topics().getInactiveTopicPolicies(topic2));
         inactiveTopicPolicies.setMaxInactiveDurationSeconds(999);
@@ -516,7 +524,7 @@ public class InactiveTopicDeleteTest extends BrokerTestBase {
         // "topic" use delete_when_no_subscriptions, "topic2" use delete_when_subscriptions_caught_up
         // "topic3" use default:delete_when_no_subscriptions
         InactiveTopicPolicies inactiveTopicPolicies =
-                new InactiveTopicPolicies(InactiveTopicDeleteMode.delete_when_no_subscriptions,1,true);
+                new InactiveTopicPolicies(InactiveTopicDeleteMode.delete_when_no_subscriptions, 1, true);
         admin.topics().setInactiveTopicPolicies(topic, inactiveTopicPolicies);
         inactiveTopicPolicies.setInactiveTopicDeleteMode(InactiveTopicDeleteMode.delete_when_subscriptions_caught_up);
         admin.topics().setInactiveTopicPolicies(topic2, inactiveTopicPolicies);
@@ -570,7 +578,8 @@ public class InactiveTopicDeleteTest extends BrokerTestBase {
         InactiveTopicPolicies policyFromBroker = admin.topics().getInactiveTopicPolicies(topic, true);
         assertEquals(policyFromBroker.getMaxInactiveDurationSeconds(), 20);
         assertFalse(policyFromBroker.isDeleteWhileInactive());
-        assertEquals(policyFromBroker.getInactiveTopicDeleteMode(), InactiveTopicDeleteMode.delete_when_no_subscriptions);
+        assertEquals(policyFromBroker.getInactiveTopicDeleteMode(),
+                InactiveTopicDeleteMode.delete_when_no_subscriptions);
         // set topic-level policy
         InactiveTopicPolicies topicLevelPolicy =
                 new InactiveTopicPolicies(InactiveTopicDeleteMode.delete_when_subscriptions_caught_up,
@@ -581,7 +590,8 @@ public class InactiveTopicDeleteTest extends BrokerTestBase {
         policyFromBroker = admin.topics().getInactiveTopicPolicies(topic, true);
         assertEquals(policyFromBroker.getMaxInactiveDurationSeconds(), 30);
         assertFalse(policyFromBroker.isDeleteWhileInactive());
-        assertEquals(policyFromBroker.getInactiveTopicDeleteMode(), InactiveTopicDeleteMode.delete_when_subscriptions_caught_up);
+        assertEquals(policyFromBroker.getInactiveTopicDeleteMode(),
+                InactiveTopicDeleteMode.delete_when_subscriptions_caught_up);
         //remove topic-level policy
         admin.topics().removeInactiveTopicPolicies(topic);
         Awaitility.await().untilAsserted(()
@@ -609,18 +619,18 @@ public class InactiveTopicDeleteTest extends BrokerTestBase {
         admin.brokers().healthcheck(TopicVersion.V1);
         admin.brokers().healthcheck(TopicVersion.V2);
 
-        List<String> V1Partitions = pulsar
+        List<String> v1Partitions = pulsar
                 .getPulsarResources()
                 .getTopicResources()
                 .getExistingPartitions(TopicName.get(healthCheckTopicV1))
                 .get(10, TimeUnit.SECONDS);
-        List<String> V2Partitions = pulsar
+        List<String> v2Partitions = pulsar
                 .getPulsarResources()
                 .getTopicResources()
                 .getExistingPartitions(TopicName.get(healthCheckTopicV2))
                 .get(10, TimeUnit.SECONDS);
-        Assert.assertTrue(V1Partitions.contains(healthCheckTopicV1));
-        Assert.assertTrue(V2Partitions.contains(healthCheckTopicV2));
+        Assert.assertTrue(v1Partitions.contains(healthCheckTopicV1));
+        Assert.assertTrue(v2Partitions.contains(healthCheckTopicV2));
     }
 
     @Test
