@@ -104,7 +104,8 @@ public class PersistentTopicConcurrentTest extends MockedBookKeeperTestCase {
         doReturn(nsSvc).when(pulsar).getNamespaceService();
         doReturn(true).when(nsSvc).isServiceUnitOwned(any(NamespaceBundle.class));
         doReturn(true).when(nsSvc).isServiceUnitActive(any(TopicName.class));
-        doReturn(CompletableFuture.completedFuture(true)).when(nsSvc).checkTopicOwnership(any(TopicName.class));
+        doReturn(CompletableFuture.completedFuture(mock(NamespaceBundle.class))).when(nsSvc).getBundleAsync(any());
+        doReturn(CompletableFuture.completedFuture(true)).when(nsSvc).checkBundleOwnership(any(), any());
 
         final List<Position> addedEntries = new ArrayList<>();
 
@@ -202,7 +203,8 @@ public class PersistentTopicConcurrentTest extends MockedBookKeeperTestCase {
                 log.info("{} forcing topic GC ", Thread.currentThread());
                 for (int i = 0; i < 2000; i++) {
                     topic.getInactiveTopicPolicies().setMaxInactiveDurationSeconds(0);
-                    topic.getInactiveTopicPolicies().setInactiveTopicDeleteMode(InactiveTopicDeleteMode.delete_when_no_subscriptions);
+                    topic.getInactiveTopicPolicies()
+                            .setInactiveTopicDeleteMode(InactiveTopicDeleteMode.delete_when_no_subscriptions);
                     topic.checkGC();
                 }
                 log.info("GC done..");
