@@ -21,7 +21,6 @@ package org.apache.pulsar.compaction;
 import static org.apache.pulsar.compaction.Compactor.COMPACTED_TOPIC_LEDGER_PROPERTY;
 import static org.apache.pulsar.compaction.Compactor.COMPACTION_SUBSCRIPTION;
 import static org.testng.Assert.assertEquals;
-import static org.testng.AssertJUnit.assertNotNull;
 import static org.testng.AssertJUnit.fail;
 import com.google.common.util.concurrent.ThreadFactoryBuilder;
 import java.io.IOException;
@@ -40,11 +39,8 @@ import org.apache.pulsar.broker.auth.MockedPulsarServiceBaseTest;
 import org.apache.pulsar.client.api.MessageRoutingMode;
 import org.apache.pulsar.client.api.Producer;
 import org.apache.pulsar.client.impl.MessageImpl;
-import org.apache.pulsar.common.api.proto.BrokerEntryMetadata;
-import org.apache.pulsar.common.api.proto.MessageMetadata;
 import org.apache.pulsar.common.policies.data.ClusterData;
 import org.apache.pulsar.common.policies.data.TenantInfoImpl;
-import org.apache.pulsar.common.protocol.Commands;
 import org.testng.annotations.AfterMethod;
 import org.testng.annotations.BeforeMethod;
 import org.testng.annotations.Test;
@@ -173,29 +169,5 @@ public class TopicCompactionServiceTest extends MockedPulsarServiceBaseTest {
 
         List<Entry> entries2 = service.readCompactedEntries(PositionFactory.EARLIEST, 1).join();
         assertEquals(entries2.size(), 1);
-
-        Entry entry = service.findEntryByEntryIndex(0).join();
-        BrokerEntryMetadata brokerEntryMetadata = Commands.peekBrokerEntryMetadataIfExist(entry.getDataBuffer());
-        assertNotNull(brokerEntryMetadata);
-        assertEquals(brokerEntryMetadata.getIndex(), 2);
-        MessageMetadata metadata = Commands.parseMessageMetadata(entry.getDataBuffer());
-        assertEquals(metadata.getPartitionKey(), "a");
-        entry.release();
-
-        entry = service.findEntryByEntryIndex(3).join();
-        brokerEntryMetadata = Commands.peekBrokerEntryMetadataIfExist(entry.getDataBuffer());
-        assertNotNull(brokerEntryMetadata);
-        assertEquals(brokerEntryMetadata.getIndex(), 4);
-        metadata = Commands.parseMessageMetadata(entry.getDataBuffer());
-        assertEquals(metadata.getPartitionKey(), "b");
-        entry.release();
-
-        entry = service.findEntryByPublishTime(startTime).join();
-        brokerEntryMetadata = Commands.peekBrokerEntryMetadataIfExist(entry.getDataBuffer());
-        assertNotNull(brokerEntryMetadata);
-        assertEquals(brokerEntryMetadata.getIndex(), 2);
-        metadata = Commands.parseMessageMetadata(entry.getDataBuffer());
-        assertEquals(metadata.getPartitionKey(), "a");
-        entry.release();
     }
 }
