@@ -81,7 +81,7 @@ import org.testng.annotations.DataProvider;
 import org.testng.annotations.Test;
 
 /**
- * Test Pulsar function state
+ * Test Pulsar function state.
  */
 @Slf4j
 @Test(groups = "functions-worker")
@@ -101,15 +101,15 @@ public class PulsarFunctionPublishTest {
     String primaryHost;
     String workerId;
 
-    private final String TLS_SERVER_CERT_FILE_PATH =
+    private static final String TLS_SERVER_CERT_FILE_PATH =
             ResourceUtils.getAbsolutePath("certificate-authority/server-keys/broker.cert.pem");
-    private final String TLS_SERVER_KEY_FILE_PATH =
+    private static final String TLS_SERVER_KEY_FILE_PATH =
             ResourceUtils.getAbsolutePath("certificate-authority/server-keys/broker.key-pk8.pem");
-    private final String TLS_CLIENT_CERT_FILE_PATH =
+    private static final String TLS_CLIENT_CERT_FILE_PATH =
             ResourceUtils.getAbsolutePath("certificate-authority/client-keys/admin.cert.pem");
-    private final String TLS_CLIENT_KEY_FILE_PATH =
+    private static final String TLS_CLIENT_KEY_FILE_PATH =
             ResourceUtils.getAbsolutePath("certificate-authority/client-keys/admin.key-pk8.pem");
-    private final String TLS_TRUST_CERT_FILE_PATH =
+    private static final String TLS_TRUST_CERT_FILE_PATH =
             ResourceUtils.getAbsolutePath("certificate-authority/certs/ca.cert.pem");
     private PulsarFunctionTestTemporaryDirectory tempDirectory;
 
@@ -292,7 +292,8 @@ public class PulsarFunctionPublishTest {
         return workerService;
     }
 
-    protected static FunctionConfig createFunctionConfig(String tenant, String namespace, String functionName, String sourceTopic, String publishTopic, String subscriptionName) {
+    protected static FunctionConfig createFunctionConfig(String tenant, String namespace, String functionName,
+                                                     String sourceTopic, String publishTopic, String subscriptionName) {
 
         FunctionConfig functionConfig = new FunctionConfig();
         functionConfig.setTenant(tenant);
@@ -329,7 +330,8 @@ public class PulsarFunctionPublishTest {
 
         // create a producer that creates a topic at broker
         Producer<String> producer = pulsarClient.newProducer(Schema.STRING).topic(sourceTopic).create();
-        Consumer<String> consumer = pulsarClient.newConsumer(Schema.STRING).topic(publishTopic).subscriptionName("sub").subscribe();
+        Consumer<String> consumer = pulsarClient.newConsumer(Schema.STRING).topic(publishTopic)
+                .subscriptionName("sub").subscribe();
 
         FunctionConfig functionConfig = createFunctionConfig(tenant, namespacePortion, functionName,
                 sourceTopic, publishTopic, subscriptionName);
@@ -354,7 +356,8 @@ public class PulsarFunctionPublishTest {
         }
         retryStrategically((test) -> {
             try {
-                SubscriptionStats subStats = admin.topics().getStats(sourceTopic).getSubscriptions().get(subscriptionName);
+                SubscriptionStats subStats =
+                        admin.topics().getStats(sourceTopic).getSubscriptions().get(subscriptionName);
                 return subStats.getUnackedMessages() == 0;
             } catch (PulsarAdminException e) {
                 return false;
@@ -381,7 +384,8 @@ public class PulsarFunctionPublishTest {
 
         // validate pulsar-sink consumer has consumed all messages and delivered to Pulsar sink but unacked messages
         // due to publish failure
-        assertNotEquals(admin.topics().getStats(sourceTopic).getSubscriptions().values().iterator().next().getUnackedMessages(),
+        assertNotEquals(admin.topics().getStats(sourceTopic).getSubscriptions()
+                        .values().iterator().next().getUnackedMessages(),
                 totalMsgs);
 
         // delete functions
@@ -425,7 +429,8 @@ public class PulsarFunctionPublishTest {
 
         //set multi webService url
         @Cleanup
-        PulsarAdmin pulsarAdmin = PulsarAdmin.builder().serviceHttpUrl(pulsar.getWebServiceAddressTls() + "," + secondAddress)
+        PulsarAdmin pulsarAdmin =
+                PulsarAdmin.builder().serviceHttpUrl(pulsar.getWebServiceAddressTls() + "," + secondAddress)
                 .tlsTrustCertsFilePath(TLS_TRUST_CERT_FILE_PATH)
                 .allowTlsInsecureConnection(true).authentication(authTls)
                 .build();
@@ -467,7 +472,8 @@ public class PulsarFunctionPublishTest {
 
         // create a producer that creates a topic at broker
         Producer<String> producer = pulsarClient.newProducer(Schema.STRING).topic(sourceTopic).create();
-        Consumer<String> consumer = pulsarClient.newConsumer(Schema.STRING).topic(publishTopic).subscriptionName("sub").subscribe();
+        Consumer<String> consumer = pulsarClient.newConsumer(Schema.STRING).topic(publishTopic)
+                .subscriptionName("sub").subscribe();
 
         FunctionConfig functionConfig = createFunctionConfig(tenant, namespacePortion, functionName,
                 sourceTopic, publishTopic, subscriptionName);
@@ -493,7 +499,8 @@ public class PulsarFunctionPublishTest {
         }
         retryStrategically((test) -> {
             try {
-                SubscriptionStats subStats = admin.topics().getStats(sourceTopic).getSubscriptions().get(subscriptionName);
+                SubscriptionStats subStats =
+                        admin.topics().getStats(sourceTopic).getSubscriptions().get(subscriptionName);
                 return subStats.getUnackedMessages() == 0;
             } catch (PulsarAdminException e) {
                 return false;
@@ -520,7 +527,8 @@ public class PulsarFunctionPublishTest {
 
         // validate pulsar-sink consumer has consumed all messages and delivered to Pulsar sink but unacked messages
         // due to publish failure
-        assertNotEquals(admin.topics().getStats(sourceTopic).getSubscriptions().values().iterator().next().getUnackedMessages(),
+        assertNotEquals(admin.topics().getStats(sourceTopic).getSubscriptions()
+                        .values().iterator().next().getUnackedMessages(),
           totalMsgs);
 
         // delete functions
@@ -542,7 +550,8 @@ public class PulsarFunctionPublishTest {
         DistributedLogConfiguration dlogConf = WorkerUtils.getDlogConf(workerConfig);
 
         // check if all function files are deleted from BK
-        String url = String.format("distributedlog://%s/pulsar/functions", "127.0.0.1" + ":" + bkEnsemble.getZookeeperPort());
+        String url = String.format("distributedlog://%s/pulsar/functions", "127.0.0.1" + ":"
+                + bkEnsemble.getZookeeperPort());
         log.info("dlog url: {}", url);
         URI dlogUri = URI.create(url);
 
@@ -554,7 +563,8 @@ public class PulsarFunctionPublishTest {
                 .build();
 
         List<String> files = new LinkedList<>();
-        dlogNamespace.getLogs(String.format("%s/%s/%s", tenant, namespacePortion, functionName)).forEachRemaining(new java.util.function.Consumer<String>() {
+        dlogNamespace.getLogs(String.format("%s/%s/%s", tenant, namespacePortion, functionName))
+                .forEachRemaining(new java.util.function.Consumer<String>() {
             @Override
             public void accept(String s) {
                 files.add(s);
