@@ -56,7 +56,7 @@ import org.testng.annotations.BeforeMethod;
 import org.testng.annotations.Test;
 
 /**
- * Test Pulsar sink on function
+ * Test Pulsar sink on function.
  *
  */
 @Slf4j
@@ -131,11 +131,26 @@ public class PulsarWorkerAssignmentTest {
     void shutdown() {
         log.info("--- Shutting down ---");
         try {
-            pulsarClient.close();
-            admin.close();
-            functionsWorkerService.stop();
-            pulsar.close();
-            bkEnsemble.stop();
+            if (pulsarClient != null) {
+                pulsarClient.close();
+                pulsarClient = null;
+            }
+            if (admin != null) {
+                admin.close();
+                admin = null;
+            }
+            if (functionsWorkerService != null) {
+                functionsWorkerService.stop();
+                functionsWorkerService = null;
+            }
+            if (pulsar != null) {
+                pulsar.close();
+                pulsar = null;
+            }
+            if (bkEnsemble != null) {
+                bkEnsemble.stop();
+                bkEnsemble = null;
+            }
         } catch (Exception e) {
             log.warn("Encountered errors at shutting down PulsarWorkerAssignmentTest", e);
         } finally {
@@ -199,15 +214,16 @@ public class PulsarWorkerAssignmentTest {
         retryStrategically((test) -> {
             try {
                 return admin.topics().getStats(sinkTopic).getSubscriptions().size() == 1
-                        && admin.topics().getStats(sinkTopic).getSubscriptions().values().iterator().next().getConsumers()
-                                .size() == 2;
+                        && admin.topics().getStats(sinkTopic).getSubscriptions().values().iterator().next()
+                        .getConsumers().size() == 2;
             } catch (PulsarAdminException e) {
                 return false;
             }
         }, 50, 150);
         // validate 2 instances have been started
         assertEquals(admin.topics().getStats(sinkTopic).getSubscriptions().size(), 1);
-        assertEquals(admin.topics().getStats(sinkTopic).getSubscriptions().values().iterator().next().getConsumers().size(), 2);
+        assertEquals(admin.topics().getStats(sinkTopic).getSubscriptions()
+                .values().iterator().next().getConsumers().size(), 2);
 
         // (2) Update function with 1 instance
         functionConfig.setParallelism(1);
@@ -216,15 +232,16 @@ public class PulsarWorkerAssignmentTest {
         retryStrategically((test) -> {
             try {
                 return admin.topics().getStats(sinkTopic).getSubscriptions().size() == 1
-                        && admin.topics().getStats(sinkTopic).getSubscriptions().values().iterator().next().getConsumers()
-                                .size() == 1;
+                        && admin.topics().getStats(sinkTopic).getSubscriptions()
+                        .values().iterator().next().getConsumers().size() == 1;
             } catch (PulsarAdminException e) {
                 return false;
             }
         }, 50, 150);
         // validate pulsar sink consumer has started on the topic
         log.info("admin.topics().getStats(sinkTopic): {}", new Gson().toJson(admin.topics().getStats(sinkTopic)));
-        assertEquals(admin.topics().getStats(sinkTopic).getSubscriptions().values().iterator().next().getConsumers().size(), 1);
+        assertEquals(admin.topics().getStats(sinkTopic).getSubscriptions()
+                .values().iterator().next().getConsumers().size(), 1);
     }
 
     @Test(timeOut = 60000, enabled = false)
