@@ -139,9 +139,6 @@ public class MemoryLimitController {
     }
 
     public double currentUsagePercent() {
-        if (!isMemoryLimited()) {
-            return 0.0;
-        }
         return 1.0 * currentUsage.get() / memoryLimit;
     }
 
