@@ -31,7 +31,7 @@ import java.util.stream.Collectors;
 import lombok.SneakyThrows;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.bookkeeper.zookeeper.BoundExponentialBackoffRetryPolicy;
-import org.apache.commons.lang3.tuple.Triple;
+import org.apache.commons.lang3.tuple.Pair;
 import org.apache.pulsar.common.util.FutureUtil;
 import org.apache.pulsar.metadata.api.GetResult;
 import org.apache.pulsar.metadata.api.MetadataStore;
@@ -54,7 +54,6 @@ import org.apache.pulsar.metadata.impl.batching.OpDelete;
 import org.apache.pulsar.metadata.impl.batching.OpGet;
 import org.apache.pulsar.metadata.impl.batching.OpGetChildren;
 import org.apache.pulsar.metadata.impl.batching.OpPut;
-import org.apache.pulsar.metadata.impl.batching.ZKMetadataStoreBatchStrategy;
 import org.apache.zookeeper.AddWatchMode;
 import org.apache.zookeeper.AsyncCallback;
 import org.apache.zookeeper.CreateMode;
@@ -111,7 +110,6 @@ public class ZKMetadataStore extends AbstractBatchedMetadataStore
                 sessionWatcher = null;
             }
             zkc.addWatch("/", eventWatcher, AddWatchMode.PERSISTENT_RECURSIVE);
-            initBatchStrategy();
         } catch (Throwable t) {
             throw new MetadataStoreException(t);
         }
@@ -119,7 +117,7 @@ public class ZKMetadataStore extends AbstractBatchedMetadataStore
 
     private void processSessionWatcher(WatchedEvent event) {
         if (sessionWatcher != null) {
-            processEvent(sessionWatcher::process, event);
+            executor.execute(() -> sessionWatcher.process(event));
         }
     }
 
@@ -146,14 +144,6 @@ public class ZKMetadataStore extends AbstractBatchedMetadataStore
         this.zkc = zkc;
         this.sessionWatcher = new ZKSessionWatcher(zkc, this::receivedSessionEvent);
         zkc.addWatch("/", eventWatcher, AddWatchMode.PERSISTENT_RECURSIVE);
-        initBatchStrategy();
-    }
-
-    private void initBatchStrategy() {
-        ZKMetadataStoreBatchStrategy batchStrategy =
-                new ZKMetadataStoreBatchStrategy(nodeSizeStats, maxOperations, maxSize, zkc);
-        this.maxSize = batchStrategy.maxSize();
-        super.metadataStoreBatchStrategy = batchStrategy;
     }
 
     @Override
@@ -214,39 +204,24 @@ public class ZKMetadataStore extends AbstractBatchedMetadataStore
 
                         // Build the log warning message
                         // summarize the operations by type
-                        final int logThresholdPut = maxSize >> 4;
-                        final int logThresholdGet = maxSize >> 4;
                         String countsByType = ops.stream().collect(
                                         Collectors.groupingBy(MetadataOp::getType, Collectors.summingInt(op -> 1)))
-                                .entrySet().stream().map(e -> e.getValue() + " " + e.getKey().name())
+                                .entrySet().stream().map(e -> e.getValue() + " " + e.getKey().name() + " entries")
                                 .collect(Collectors.joining(", "));
-                        boolean shouldLimitLogLen = ops.size() > 16;
-                        List<Triple<String, String, Integer>> opsForLog = ops.stream()
-                                .filter(item -> {
-                                    if (!shouldLimitLogLen) {
-                                        return true;
-                                    }
-                                    return switch (item.getType()) {
-                                        case PUT -> item.asPut().getData().length > logThresholdPut;
-                                        case GET -> nodeSizeStats
-                                                .getMaxSizeOfSameResourceType(item.getPath()) > logThresholdGet;
-                                        case GET_CHILDREN -> nodeSizeStats
-                                                .getMaxChildrenCountOfSameResourceType(item.getPath()) > 512;
-                                        default -> false;
-                                    };
-                                })
-                                .map(op -> Triple.of(op.getPath(), op.getType().toString(), op.size()))
+                        List<Pair> opsForLog = ops.stream()
+                                .filter(item -> item.size() > 256 * 1024)
+                                .map(op -> Pair.of(op.getPath(), op.size()))
                                 .collect(Collectors.toList());
                         Long totalSize = ops.stream().collect(Collectors.summingLong(MetadataOp::size));
                         log.warn("Connection loss while executing batch operation of {} "
-                                + "of total requested data size of {}. "
-                                + "Retrying individual operations one-by-one."
-                                + " ops that maybe large: {}",
+                                + "of total data size of {}. "
+                                + "Retrying individual operations one-by-one. ops whose size > 256KB: {}",
                                 countsByType, totalSize, opsForLog);
 
                         // Retry with the individual operations
-                        scheduleDelayedTask(100, TimeUnit.MILLISECONDS,
-                            () -> ops.forEach(o -> batchOperation(Collections.singletonList(o))));
+                        executor.schedule(() -> {
+                            ops.forEach(o -> batchOperation(Collections.singletonList(o)));
+                        }, 100, TimeUnit.MILLISECONDS);
                     } else {
                         MetadataStoreException e = getException(code, path);
                         ops.forEach(o -> o.getFuture().completeExceptionally(e));
@@ -255,7 +230,7 @@ public class ZKMetadataStore extends AbstractBatchedMetadataStore
                 }
 
                 // Trigger all the futures in the batch
-                safeExecuteCallbacks(() -> {
+                execute(() -> {
                     for (int i = 0; i < ops.size(); i++) {
                         OpResult opr = results.get(i);
                         MetadataOp op = ops.get(i);
@@ -277,7 +252,7 @@ public class ZKMetadataStore extends AbstractBatchedMetadataStore
                                             "Operation type not supported in multi: " + op.getType()));
                             }
                         }
-                }, ops);
+                }, () -> ops.stream().map(MetadataOp::getFuture).collect(Collectors.toList()));
             }, null);
         } catch (Throwable t) {
             ops.forEach(o -> o.getFuture().completeExceptionally(new MetadataStoreException(t)));
@@ -394,7 +369,7 @@ public class ZKMetadataStore extends AbstractBatchedMetadataStore
 
         try {
             zkc.exists(path, null, (rc, path1, ctx, stat) -> {
-                safeExecuteCallback(() -> {
+                execute(() -> {
                     Code code = Code.get(rc);
                     if (code == Code.OK) {
                         future.complete(true);
@@ -420,7 +395,7 @@ public class ZKMetadataStore extends AbstractBatchedMetadataStore
 
         try {
             zkc.delete(op.getPath(), expectedVersion, (rc, path1, ctx) -> {
-                safeExecuteCallback(() -> {
+                execute(() -> {
                     Code code = Code.get(rc);
                     if (code == Code.OK) {
                         future.complete(null);
@@ -445,7 +420,7 @@ public class ZKMetadataStore extends AbstractBatchedMetadataStore
                 CreateMode createMode = getCreateMode(opPut.getOptions());
                 asyncCreateFullPathOptimistic(zkc, opPut.getPath(), opPut.getData(), createMode,
                         (rc, path1, ctx, name) -> {
-                            safeExecuteCallback(() -> {
+                            execute(() -> {
                                 Code code = Code.get(rc);
                                 if (code == Code.OK) {
                                     future.complete(new Stat(name, 0, 0, 0, createMode.isEphemeral(), true));
@@ -459,7 +434,7 @@ public class ZKMetadataStore extends AbstractBatchedMetadataStore
                         });
             } else {
                 zkc.setData(opPut.getPath(), opPut.getData(), expectedVersion, (rc, path1, ctx, stat) -> {
-                    safeExecuteCallback(() -> {
+                    execute(() -> {
                         Code code = Code.get(rc);
                         if (code == Code.OK) {
                             future.complete(getStat(path1, stat));
