@@ -18,6 +18,7 @@
  */
 package org.apache.pulsar.metadata.impl.batching;
 
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.EnumSet;
 import java.util.List;
@@ -27,7 +28,6 @@ import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 import lombok.extern.slf4j.Slf4j;
-import org.apache.commons.collections4.CollectionUtils;
 import org.apache.pulsar.metadata.api.GetResult;
 import org.apache.pulsar.metadata.api.MetadataEventSynchronizer;
 import org.apache.pulsar.metadata.api.MetadataStoreConfig;
@@ -50,14 +50,13 @@ public abstract class AbstractBatchedMetadataStore extends AbstractMetadataStore
 
     private final boolean enabled;
     private final int maxDelayMillis;
-    protected final int maxOperations;
-    protected int maxSize;
+    private final int maxOperations;
+    private final int maxSize;
     private MetadataEventSynchronizer synchronizer;
     private final BatchMetadataStoreStats batchMetadataStoreStats;
-    protected MetadataStoreBatchStrategy metadataStoreBatchStrategy;
 
     protected AbstractBatchedMetadataStore(MetadataStoreConfig conf) {
-        super(conf.getMetadataStoreName(), conf.getOpenTelemetry(), conf.getNodeSizeStats());
+        super(conf.getMetadataStoreName(), conf.getOpenTelemetry());
 
         this.enabled = conf.isBatchingEnabled();
         this.maxDelayMillis = conf.getBatchingMaxDelayMillis();
@@ -79,7 +78,6 @@ public abstract class AbstractBatchedMetadataStore extends AbstractMetadataStore
         updateMetadataEventSynchronizer(conf.getSynchronizer());
         this.batchMetadataStoreStats =
                 new BatchMetadataStoreStats(metadataStoreName, executor, conf.getOpenTelemetry());
-        this.metadataStoreBatchStrategy = new DefaultMetadataStoreBatchStrategy(maxOperations, maxSize);
     }
 
     @Override
@@ -102,16 +100,37 @@ public abstract class AbstractBatchedMetadataStore extends AbstractMetadataStore
     }
 
     private void flush() {
-        List<MetadataOp> currentBatch;
-        if (!readOps.isEmpty()) {
-            while (CollectionUtils.isNotEmpty(currentBatch = metadataStoreBatchStrategy.nextBatch(readOps))) {
-                internalBatchOperation(currentBatch);
+        while (!readOps.isEmpty()) {
+            List<MetadataOp> ops = new ArrayList<>();
+            for (int i = 0; i < maxOperations; i++) {
+                MetadataOp op = readOps.poll();
+                if (op == null) {
+                    break;
+                }
+                ops.add(op);
             }
+            internalBatchOperation(ops);
         }
-        if (!writeOps.isEmpty()) {
-            while (CollectionUtils.isNotEmpty(currentBatch = metadataStoreBatchStrategy.nextBatch(writeOps))) {
-                internalBatchOperation(currentBatch);
+
+        while (!writeOps.isEmpty()) {
+            int batchSize = 0;
+
+            List<MetadataOp> ops = new ArrayList<>();
+            for (int i = 0; i < maxOperations; i++) {
+                MetadataOp op = writeOps.peek();
+                if (op == null) {
+                    break;
+                }
+
+                if (i > 0 && (batchSize + op.size()) > maxSize) {
+                    // We have already reached the max size, so flush the current batch
+                    break;
+                }
+
+                batchSize += op.size();
+                ops.add(writeOps.poll());
             }
+            internalBatchOperation(ops);
         }
 
         flushInProgress.set(false);
