@@ -44,8 +44,6 @@ import org.apache.pulsar.client.api.SubscriptionType;
 import org.apache.pulsar.common.functions.FunctionState;
 import org.apache.pulsar.common.policies.data.SinkStatus;
 import org.apache.pulsar.common.policies.data.SourceStatus;
-import org.apache.pulsar.functions.api.examples.WordCountFunction;
-import org.apache.pulsar.functions.instance.state.PulsarMetadataStateStoreProviderImpl;
 import org.apache.pulsar.tests.integration.docker.ContainerExecException;
 import org.apache.pulsar.tests.integration.docker.ContainerExecResult;
 import org.apache.pulsar.tests.integration.functions.utils.CommandGenerator;
@@ -59,49 +57,37 @@ import org.testng.annotations.Test;
  * State related test cases.
  */
 @Slf4j
-public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
-
-    protected String stateStoreProvider;
-
-    protected PulsarStateTest(String stateStoreProvider) {
-        super();
-        this.stateStoreProvider = stateStoreProvider;
-    }
+public class PulsarStateTest extends PulsarStandaloneTestSuite {
 
     public static final String WORDCOUNT_PYTHON_CLASS =
-            "wordcount_function.WordCountFunction";
-    public static final String WORDCOUNT_JAVA_CLASS = WordCountFunction.class.getName();
+        "wordcount_function.WordCountFunction";
 
     public static final String WORDCOUNT_PYTHON_FILE = "wordcount_function.py";
 
     public static final String VALUE_BASE64 = "0a8001127e0a172e6576656e74732e437573746f6d65724372656174656412630a243"
-            + "2336366666263652d623038342d346631352d616565342d326330643135356131666"
-            + "36312026e311a3700000000000000000000000000000000000000000000000000000"
-            + "000000000000000000000000000000000000000000000000000000000";
+                                              + "2336366666263652d623038342d346631352d616565342d326330643135356131666"
+                                              + "36312026e311a3700000000000000000000000000000000000000000000000000000"
+                                              + "000000000000000000000000000000000000000000000000000000000";
+
+    @Test(groups = {"python_state", "state", "function", "python_function"})
+    public void testPythonWordCountFunction() throws Exception {
+        String functionName = "test-wordcount-py-fn-" + randomName(8);
+        doTestPythonWordCountFunction(functionName);
+
+        // after a function is deleted, its state should be clean
+        // we just recreate and test the word count function again, and it should have same result
+        doTestPythonWordCountFunction(functionName);
+    }
 
     private void doTestPythonWordCountFunction(String functionName) throws Exception {
         String inputTopicName = "test-wordcount-py-input-" + randomName(8);
         String outputTopicName = "test-wordcount-py-output-" + randomName(8);
 
-        // submit the word count function
-        submitWordCountFunction(
-                Runtime.PYTHON, inputTopicName, outputTopicName, functionName);
-        // run tests
-        doTestFunction(functionName, inputTopicName, outputTopicName);
-    }
-
-    private void doTestJavaWordCountFunction(String functionName) throws Exception {
-        String inputTopicName = "test-wordcount-java-input-" + randomName(8);
-
-        // submit the word count function
-        submitWordCountFunction(
-                Runtime.JAVA, inputTopicName, null, functionName);
-        // run tests
-        doTestFunction(functionName, inputTopicName, null);
-    }
-
-    private void doTestFunction(String functionName, String inputTopicName, String outputTopicName) throws Exception {
         final int numMessages = 10;
+        // submit the exclamation function
+        submitExclamationFunction(
+                Runtime.PYTHON, inputTopicName, outputTopicName, functionName);
+
         // get function info
         getFunctionInfoSuccess(functionName);
 
@@ -138,7 +124,8 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
         String byteStrState = "{\"key\":\"test-str-bytes\",\"byteValue\":\"" + bytesStrString + "\"}";
         putAndQueryState(functionName, "test-str-bytes", byteStrState, valueStr);
 
-        String byteStrStateWithEmptyValues = "{\"key\":\"test-str-bytes\",\"byteValue\":\"" + bytesStrString + "\",\"stringValue\":\"\",\"numberValue\":0}";
+        String byteStrStateWithEmptyValues = "{\"key\":\"test-str-bytes\",\"byteValue\":\"" + bytesStrString + "\","
+                + "\"stringValue\":\"\",\"numberValue\":0}";
         putAndQueryState(functionName, "test-str-bytes", byteStrStateWithEmptyValues, valueStr);
 
         // delete function
@@ -148,37 +135,13 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
         getFunctionInfoNotFound(functionName);
     }
 
-    @Test(groups = {"python_state", "state", "function", "python_function"})
-    public void testPythonWordCountFunction() throws Exception {
-        if (PulsarMetadataStateStoreProviderImpl.class.getName().equals(stateStoreProvider)) {
-            // python function doesn't support metadata state store yet
-            return;
-        }
-        String functionName = "test-wordcount-py-fn-" + randomName(8);
-        doTestPythonWordCountFunction(functionName);
-
-        // after a function is deleted, its state should be clean
-        // we just recreate and test the word count function again, and it should have same result
-        doTestPythonWordCountFunction(functionName);
-    }
-
-    @Test(groups = {"java_state", "state", "function", "java_function"})
-    public void testJavaWordCountFunction() throws Exception {
-        String functionName = "test-wordcount-java-fn-" + randomName(8);
-        doTestJavaWordCountFunction(functionName);
-
-        // after a function is deleted, its state should be clean
-        // we just recreate and test the word count function again, and it should have same result
-        doTestJavaWordCountFunction(functionName);
-    }
-
-
     @Test(groups = {"java_state", "state", "function", "java_function"})
     public void testSourceState() throws Exception {
         String outputTopicName = "test-state-source-output-" + randomName(8);
         String sourceName = "test-state-source-" + randomName(8);
 
-        submitSourceConnector(sourceName, outputTopicName, "org.apache.pulsar.tests.integration.io.TestStateSource",  JAVAJAR);
+        submitSourceConnector(sourceName, outputTopicName, "org.apache.pulsar.tests.integration.io.TestStateSource",
+                JAVAJAR);
 
         // get source info
         getSourceInfoSuccess(sourceName);
@@ -217,7 +180,8 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
             }
 
             Awaitility.await().ignoreExceptions().untilAsserted(() -> {
-                FunctionState functionState = admin.functions().getFunctionState("public", "default", sourceName, "now");
+                FunctionState functionState =
+                        admin.functions().getFunctionState("public", "default", sourceName, "now");
                 assertTrue(functionState.getStringValue().matches("val1-.*"));
             });
         }
@@ -234,7 +198,7 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
         String sinkName = "test-state-sink-" + randomName(8);
         int numMessages = 10;
 
-        submitSinkConnector(sinkName, inputTopicName, "org.apache.pulsar.tests.integration.io.TestStateSink", JAVAJAR);
+        submitSinkConnector(sinkName, inputTopicName, "org.apache.pulsar.tests.integration.io.TestStateSink",  JAVAJAR);
 
         // get sink info
         getSinkInfoSuccess(sinkName);
@@ -322,7 +286,8 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
         String outputTopicName = "test-state-source-output-" + randomName(8);
         String sourceName = "test-state-source-" + randomName(8);
 
-        submitSourceConnector(sourceName, outputTopicName, "org.apache.pulsar.tests.integration.io.TestByteStateSource",  JAVAJAR);
+        submitSourceConnector(sourceName, outputTopicName,
+                "org.apache.pulsar.tests.integration.io.TestByteStateSource", JAVAJAR);
 
         // get source info
         getSourceInfoSuccess(sourceName);
@@ -346,7 +311,8 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
             }
 
             Awaitility.await().ignoreExceptions().untilAsserted(() -> {
-                FunctionState functionState = admin.functions().getFunctionState("public", "default", sourceName, "now");
+                FunctionState functionState =
+                        admin.functions().getFunctionState("public", "default", sourceName, "now");
                 assertNull(functionState.getStringValue());
                 assertEquals(functionState.getByteValue(), Base64.getDecoder().decode(VALUE_BASE64));
             });
@@ -359,9 +325,9 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
     }
 
     private void submitSourceConnector(String sourceName,
-                                       String outputTopicName,
-                                       String className,
-                                       String archive) throws Exception {
+                                         String outputTopicName,
+                                         String className,
+                                         String archive) throws Exception {
         String[] commands = {
                 PulsarCluster.ADMIN_SCRIPT,
                 "sources", "create",
@@ -378,9 +344,9 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
     }
 
     private void submitSinkConnector(String sinkName,
-                                     String inputTopicName,
-                                     String className,
-                                     String archive) throws Exception {
+                                         String inputTopicName,
+                                         String className,
+                                         String archive) throws Exception {
         String[] commands = {
                 PulsarCluster.ADMIN_SCRIPT,
                 "sinks", "create",
@@ -396,35 +362,33 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
                 result.getStdout());
     }
 
-    private void submitWordCountFunction(Runtime runtime,
-                                         String inputTopicName,
-                                         String outputTopicName,
-                                         String functionName) throws Exception {
+    private void submitExclamationFunction(Runtime runtime,
+                                                  String inputTopicName,
+                                                  String outputTopicName,
+                                                  String functionName) throws Exception {
         submitFunction(
-                runtime,
-                inputTopicName,
-                outputTopicName,
-                functionName,
-                getWordCountClass(runtime),
-                Schema.BYTES);
+            runtime,
+            inputTopicName,
+            outputTopicName,
+            functionName,
+            getExclamationClass(runtime),
+            Schema.BYTES);
     }
 
-    protected static String getWordCountClass(Runtime runtime) {
+    protected static String getExclamationClass(Runtime runtime) {
         if (Runtime.PYTHON == runtime) {
             return WORDCOUNT_PYTHON_CLASS;
-        } else if (Runtime.JAVA == runtime) {
-            return WORDCOUNT_JAVA_CLASS;
         } else {
             throw new IllegalArgumentException("Unsupported runtime : " + runtime);
         }
     }
 
     private <T> void submitFunction(Runtime runtime,
-                                    String inputTopicName,
-                                    String outputTopicName,
-                                    String functionName,
-                                    String functionClass,
-                                    Schema<T> inputTopicSchema) throws Exception {
+                                           String inputTopicName,
+                                           String outputTopicName,
+                                           String functionName,
+                                           String functionClass,
+                                           Schema<T> inputTopicSchema) throws Exception {
         CommandGenerator generator;
         generator = CommandGenerator.createDefaultGenerator(inputTopicName, functionClass);
         generator.setSinkTopic(outputTopicName);
@@ -439,10 +403,10 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
             throw new IllegalArgumentException("Unsupported runtime : " + runtime);
         }
         String[] commands = {
-                "sh", "-c", command
+            "sh", "-c", command
         };
         ContainerExecResult result = container.execCmd(
-                commands);
+            commands);
         assertTrue(result.getStdout().contains("Created successfully"));
 
         ensureSubscriptionCreated(inputTopicName, String.format("public/default/%s", functionName), inputTopicSchema);
@@ -450,18 +414,18 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
 
     @SuppressWarnings("try")
     private <T> void ensureSubscriptionCreated(String inputTopicName,
-                                               String subscriptionName,
-                                               Schema<T> inputTopicSchema)
+                                                      String subscriptionName,
+                                                      Schema<T> inputTopicSchema)
             throws Exception {
         // ensure the function subscription exists before we start producing messages
         try (PulsarClient client = PulsarClient.builder()
-                .serviceUrl(container.getPlainTextServiceUrl())
-                .build()) {
+            .serviceUrl(container.getPlainTextServiceUrl())
+            .build()) {
             try (Consumer<T> ignored = client.newConsumer(inputTopicSchema)
-                    .topic(inputTopicName)
-                    .subscriptionType(SubscriptionType.Shared)
-                    .subscriptionName(subscriptionName)
-                    .subscribe()) {
+                .topic(inputTopicName)
+                .subscriptionType(SubscriptionType.Shared)
+                .subscriptionName(subscriptionName)
+                .subscribe()) {
             }
         }
     }
@@ -492,12 +456,12 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
 
     private void getFunctionInfoSuccess(String functionName) throws Exception {
         ContainerExecResult result = container.execCmd(
-                PulsarCluster.ADMIN_SCRIPT,
-                "functions",
-                "get",
-                "--tenant", "public",
-                "--namespace", "default",
-                "--name", functionName
+            PulsarCluster.ADMIN_SCRIPT,
+            "functions",
+            "get",
+            "--tenant", "public",
+            "--namespace", "default",
+            "--name", functionName
         );
         assertTrue(result.getStdout().contains("\"name\": \"" + functionName + "\""));
     }
@@ -543,27 +507,27 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
 
     private void getFunctionStatus(String functionName, int numMessages) throws Exception {
         ContainerExecResult result = container.execCmd(
-                PulsarCluster.ADMIN_SCRIPT,
-                "functions",
-                "getstatus",
-                "--tenant", "public",
-                "--namespace", "default",
-                "--name", functionName
+            PulsarCluster.ADMIN_SCRIPT,
+            "functions",
+            "getstatus",
+            "--tenant", "public",
+            "--namespace", "default",
+            "--name", functionName
         );
         assertTrue(result.getStdout().contains("\"running\" : true"));
         assertTrue(result.getStdout().contains("\"numSuccessfullyProcessed\" : " + numMessages));
     }
 
     private void queryState(String functionName, String key, int amount, long version)
-            throws Exception {
+        throws Exception {
         ContainerExecResult result = container.execCmd(
-                PulsarCluster.ADMIN_SCRIPT,
-                "functions",
-                "querystate",
-                "--tenant", "public",
-                "--namespace", "default",
-                "--name", functionName,
-                "--key", key
+            PulsarCluster.ADMIN_SCRIPT,
+            "functions",
+            "querystate",
+            "--tenant", "public",
+            "--namespace", "default",
+            "--name", functionName,
+            "--key", key
         );
         assertTrue(result.getStdout().contains("\"numberValue\": " + amount));
         assertTrue(result.getStdout().contains("\"version\": " + version));
@@ -623,27 +587,24 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
     }
 
     private void publishAndConsumeMessages(String inputTopic,
-                                           String outputTopic,
-                                           int numMessages) throws Exception {
+                                                  String outputTopic,
+                                                  int numMessages) throws Exception {
         @Cleanup PulsarClient client = PulsarClient.builder()
-                .serviceUrl(container.getPlainTextServiceUrl())
-                .build();
+            .serviceUrl(container.getPlainTextServiceUrl())
+            .build();
+        @Cleanup Consumer<byte[]> consumer = client.newConsumer(Schema.BYTES)
+            .topic(outputTopic)
+            .subscriptionType(SubscriptionType.Exclusive)
+            .subscriptionName("test-sub")
+            .subscribe();
         @Cleanup Producer<byte[]> producer = client.newProducer(Schema.BYTES)
-                .topic(inputTopic)
-                .create();
+            .topic(inputTopic)
+            .create();
 
         for (int i = 0; i < numMessages; i++) {
             producer.send(("hello test message-" + i).getBytes(UTF_8));
         }
 
-        if (outputTopic == null) {
-            return;
-        }
-        @Cleanup Consumer<byte[]> consumer = client.newConsumer(Schema.BYTES)
-                .topic(outputTopic)
-                .subscriptionType(SubscriptionType.Exclusive)
-                .subscriptionName("test-sub")
-                .subscribe();
         for (int i = 0; i < numMessages; i++) {
             Message<byte[]> msg = consumer.receive();
             assertEquals("hello test message-" + i + "!", new String(msg.getValue(), UTF_8));
@@ -652,12 +613,12 @@ public abstract class PulsarStateTest extends PulsarStandaloneTestSuite {
 
     private void deleteFunction(String functionName) throws Exception {
         ContainerExecResult result = container.execCmd(
-                PulsarCluster.ADMIN_SCRIPT,
-                "functions",
-                "delete",
-                "--tenant", "public",
-                "--namespace", "default",
-                "--name", functionName
+            PulsarCluster.ADMIN_SCRIPT,
+            "functions",
+            "delete",
+            "--tenant", "public",
+            "--namespace", "default",
+            "--name", functionName
         );
         assertTrue(result.getStdout().contains("Deleted successfully"));
         result.assertNoStderr();
